# Cache Cleanup Report

**Directory:** /Users/vladimirpavlov/PycharmProjects/Pythagoras
**Date:** 2026-01-05 01:23:11
**Items removed:** 189

## Removed Items

- .pytest_cache
- src/pythagoras/__pycache__
- src/pythagoras/_340_autonomous_code_portals/__pycache__
- src/pythagoras/core/__pycache__
- src/pythagoras/_110_supporting_utilities/__pycache__
- src/pythagoras/_360_pure_code_portals/__pycache__
- src/pythagoras/_350_protected_code_portals/__pycache__
- src/pythagoras/_800_top_level_API/__pycache__
- src/pythagoras/_310_ordinary_code_portals/__pycache__
- src/pythagoras/_330_safe_code_portals/__pycache__
- src/pythagoras/_210_basic_portals/__pycache__
- src/pythagoras/_220_data_portals/__pycache__
- src/pythagoras/_320_logging_code_portals/__pycache__
- src/pythagoras/_230_configurable_portals/__pycache__
- src/pythagoras/_410_swarming_portals/__pycache__
- .venv/lib/python3.13/site-packages/__pycache__
- .venv/lib/python3.13/site-packages/deepdiff/__pycache__
- .venv/lib/python3.13/site-packages/s3transfer/__pycache__
- .venv/lib/python3.13/site-packages/pygments/__pycache__
- .venv/lib/python3.13/site-packages/pytest/__pycache__
- .venv/lib/python3.13/site-packages/_polars_runtime_32/__pycache__
- .venv/lib/python3.13/site-packages/lz4/__pycache__
- .venv/lib/python3.13/site-packages/pytz/__pycache__
- .venv/lib/python3.13/site-packages/numpy/__pycache__
- .venv/lib/python3.13/site-packages/botocore/__pycache__
- .venv/lib/python3.13/site-packages/pip/__pycache__
- .venv/lib/python3.13/site-packages/uv/__pycache__
- .venv/lib/python3.13/site-packages/joblib/__pycache__
- .venv/lib/python3.13/site-packages/certifi/__pycache__
- .venv/lib/python3.13/site-packages/orderly_set/__pycache__
- .venv/lib/python3.13/site-packages/mixinforge/__pycache__
- .venv/lib/python3.13/site-packages/jsonpickle/__pycache__
- .venv/lib/python3.13/site-packages/pluggy/__pycache__
- .venv/lib/python3.13/site-packages/yaml/__pycache__
- .venv/lib/python3.13/site-packages/jmespath/__pycache__
- .venv/lib/python3.13/site-packages/urllib3/__pycache__
- .venv/lib/python3.13/site-packages/persidict/__pycache__
- .venv/lib/python3.13/site-packages/_distutils_hack/__pycache__
- .venv/lib/python3.13/site-packages/iniconfig/__pycache__
- .venv/lib/python3.13/site-packages/psutil/__pycache__
- .venv/lib/python3.13/site-packages/pandas/__pycache__
- .venv/lib/python3.13/site-packages/dateutil/__pycache__
- .venv/lib/python3.13/site-packages/_pytest/__pycache__
- .venv/lib/python3.13/site-packages/boto3/__pycache__
- .venv/lib/python3.13/site-packages/boto3/resources/__pycache__
- .venv/lib/python3.13/site-packages/boto3/docs/__pycache__
- .venv/lib/python3.13/site-packages/_pytest/config/__pycache__
- .venv/lib/python3.13/site-packages/_pytest/mark/__pycache__
- .venv/lib/python3.13/site-packages/_pytest/_code/__pycache__
- .venv/lib/python3.13/site-packages/_pytest/assertion/__pycache__
- .venv/lib/python3.13/site-packages/_pytest/_io/__pycache__
- .venv/lib/python3.13/site-packages/_pytest/_py/__pycache__
- .venv/lib/python3.13/site-packages/dateutil/parser/__pycache__
- .venv/lib/python3.13/site-packages/dateutil/tz/__pycache__
- .venv/lib/python3.13/site-packages/pandas/compat/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/__pycache__
- .venv/lib/python3.13/site-packages/pandas/util/__pycache__
- .venv/lib/python3.13/site-packages/pandas/io/__pycache__
- .venv/lib/python3.13/site-packages/pandas/tseries/__pycache__
- .venv/lib/python3.13/site-packages/pandas/_testing/__pycache__
- .venv/lib/python3.13/site-packages/pandas/_libs/__pycache__
- .venv/lib/python3.13/site-packages/pandas/plotting/__pycache__
- .venv/lib/python3.13/site-packages/pandas/arrays/__pycache__
- .venv/lib/python3.13/site-packages/pandas/api/__pycache__
- .venv/lib/python3.13/site-packages/pandas/errors/__pycache__
- .venv/lib/python3.13/site-packages/pandas/_config/__pycache__
- .venv/lib/python3.13/site-packages/pandas/api/indexers/__pycache__
- .venv/lib/python3.13/site-packages/pandas/api/types/__pycache__
- .venv/lib/python3.13/site-packages/pandas/api/interchange/__pycache__
- .venv/lib/python3.13/site-packages/pandas/api/extensions/__pycache__
- .venv/lib/python3.13/site-packages/pandas/api/typing/__pycache__
- .venv/lib/python3.13/site-packages/pandas/_libs/window/__pycache__
- .venv/lib/python3.13/site-packages/pandas/_libs/tslibs/__pycache__
- .venv/lib/python3.13/site-packages/pandas/io/parsers/__pycache__
- .venv/lib/python3.13/site-packages/pandas/io/formats/__pycache__
- .venv/lib/python3.13/site-packages/pandas/io/excel/__pycache__
- .venv/lib/python3.13/site-packages/pandas/io/json/__pycache__
- .venv/lib/python3.13/site-packages/pandas/io/sas/__pycache__
- .venv/lib/python3.13/site-packages/pandas/util/version/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/indexers/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/reshape/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/strings/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/tools/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/methods/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/util/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/array_algos/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/interchange/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/dtypes/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/groupby/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/internals/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/computation/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/_numba/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/window/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/arrays/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/ops/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/indexes/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/arrays/arrow/__pycache__
- .venv/lib/python3.13/site-packages/pandas/core/arrays/sparse/__pycache__
- .venv/lib/python3.13/site-packages/pandas/compat/numpy/__pycache__
- .venv/lib/python3.13/site-packages/urllib3/util/__pycache__
- .venv/lib/python3.13/site-packages/urllib3/contrib/__pycache__
- .venv/lib/python3.13/site-packages/urllib3/http2/__pycache__
- .venv/lib/python3.13/site-packages/jsonpickle/ext/__pycache__
- .venv/lib/python3.13/site-packages/joblib/externals/__pycache__
- .venv/lib/python3.13/site-packages/joblib/externals/cloudpickle/__pycache__
- .venv/lib/python3.13/site-packages/joblib/externals/loky/__pycache__
- .venv/lib/python3.13/site-packages/joblib/externals/loky/backend/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/packaging/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/truststore/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/msgpack/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/dependency_groups/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/pygments/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/distlib/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/cachecontrol/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/idna/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/requests/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/certifi/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/pyproject_hooks/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/rich/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/urllib3/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/resolvelib/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/platformdirs/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/resolvelib/resolvers/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/urllib3/util/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/urllib3/contrib/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/urllib3/packages/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/pyproject_hooks/_in_process/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/cachecontrol/caches/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/pygments/filters/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/pygments/lexers/__pycache__
- .venv/lib/python3.13/site-packages/pip/_vendor/pygments/styles/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/network/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/utils/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/models/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/cli/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/operations/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/req/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/resolution/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/vcs/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/locations/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/index/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/commands/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/metadata/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/distributions/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/metadata/importlib/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/resolution/resolvelib/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/operations/install/__pycache__
- .venv/lib/python3.13/site-packages/pip/_internal/operations/build/__pycache__
- .venv/lib/python3.13/site-packages/botocore/docs/__pycache__
- .venv/lib/python3.13/site-packages/botocore/retries/__pycache__
- .venv/lib/python3.13/site-packages/botocore/vendored/__pycache__
- .venv/lib/python3.13/site-packages/botocore/crt/__pycache__
- .venv/lib/python3.13/site-packages/botocore/vendored/requests/__pycache__
- .venv/lib/python3.13/site-packages/botocore/vendored/requests/packages/__pycache__
- .venv/lib/python3.13/site-packages/botocore/vendored/requests/packages/urllib3/__pycache__
- .venv/lib/python3.13/site-packages/botocore/docs/bcdoc/__pycache__
- .venv/lib/python3.13/site-packages/numpy/_utils/__pycache__
- .venv/lib/python3.13/site-packages/numpy/linalg/__pycache__
- .venv/lib/python3.13/site-packages/numpy/ma/__pycache__
- .venv/lib/python3.13/site-packages/numpy/_core/__pycache__
- .venv/lib/python3.13/site-packages/numpy/_typing/__pycache__
- .venv/lib/python3.13/site-packages/numpy/rec/__pycache__
- .venv/lib/python3.13/site-packages/numpy/lib/__pycache__
- .venv/lib/python3.13/site-packages/numpy/random/__pycache__
- .venv/lib/python3.13/site-packages/numpy/matrixlib/__pycache__
- .venv/lib/python3.13/site-packages/lz4/frame/__pycache__
- .venv/lib/python3.13/site-packages/pygments/filters/__pycache__
- .venv/lib/python3.13/site-packages/pygments/lexers/__pycache__
- .venv/lib/python3.13/site-packages/pygments/formatters/__pycache__
- .venv/lib/python3.13/site-packages/pygments/styles/__pycache__
- tests/_340_autonomous_code_portals/__pycache__
- tests/core/__pycache__
- tests/_110_supporting_utilities/__pycache__
- tests/_360_pure_code_portals/__pycache__
- tests/_350_protected_code_portals/__pycache__
- tests/_800_top_level_API/__pycache__
- tests/_310_ordinary_code_portals/__pycache__
- tests/_330_safe_code_portals/__pycache__
- tests/_000_simple_imports/__pycache__
- tests/_210_basic_portals/__pycache__
- tests/_220_data_portals/__pycache__
- tests/_320_logging_code_portals/__pycache__
- tests/_410_swarming_portals/__pycache__
- tests/_360_pure_code_portals/decorator/__pycache__
- tests/_360_pure_code_portals/guards/__pycache__
- tests/_340_autonomous_code_portals/decorators/__pycache__
- tests/_340_autonomous_code_portals/dependency_analyzer/__pycache__
